import { Component, ViewChild } from '@angular/core';
import { FormBuilder, FormGroup, NgForm, Validators } from '@angular/forms';
import { ActivatedRoute, Router } from '@angular/router';
import { BlockUI, NgBlockUI } from 'ng-block-ui';
import { BuildingService } from '../../service/monitoring-api.service';

@Component({
  selector: 'app-add-edit-list',
  templateUrl: './add-edit-list.component.html',
  styleUrls: ['./add-edit-list.component.css']
})
export class AddEditListComponent {
  @ViewChild("f", { read: true }) userProfileForm: NgForm;

  model: any = {};
  mode: string;
  public breadcrumb: any;
  projectInfo: FormGroup;
  submitted = false;

  dataBuildingList: any;
  dataRoomList: any;
  dataMasterStatus: any

  @BlockUI("projectInfo") blockUIProjectInfo: NgBlockUI;

  constructor(
    private formBuilder: FormBuilder,
    private router: Router,
    private route: ActivatedRoute,
    private monitoringApiService: BuildingService,
  ) {}

  ngOnInit() {
    this.route.data.subscribe((data) => {
      this.mode = data.mode;
    });
    this.setBreadcrumb();
    this.dataListBuilding();
    this.dataListRoom();
    this.dataListMaster();

    this.projectInfo = this.formBuilder.group({
      buildingId: ["", Validators.required],
      roomId: ["", Validators.required],
      statusId: ["", Validators.required],
    });
  }

  setBreadcrumb() {
    if (this.isAddMode()) {
      this.breadcrumb = {
        mainlabel: "Cost Management",
        links: [
          {
            name: "Home",
            isLink: false,
          },
          {
            name: "Cost Management",
            isLink: false,
          },
          {
            name: "Add New Cost Management",
            isLink: false,
          },
        ],
      };
    } else if (this.isEditMode()) {
      this.breadcrumb = {
        mainlabel: "Cost Management",
        links: [
          {
            name: "Home",
            isLink: false,
          },
          {
            name: "Cost Management",
            isLink: false,
          },
          {
            name: "Edit New Cost Management",
            isLink: false,
          },
        ],
      };
    } else if (this.isViewMode()) {
      this.breadcrumb = {
        mainlabel: "Cost Management",
        links: [
          {
            name: "Home",
            isLink: false,
          },
          {
            name: "Cost Management",
            isLink: false,
          },
          {
            name: "View New Cost Management",
            isLink: false,
          },
        ],
      };
    }
  }

  isEditMode() {
    return this.mode === "edit";
  }

  isViewMode() {
    return this.mode === "view";
  }

  isAddMode() {
    return this.mode === "add";
  }

  get f() {
    return this.projectInfo.controls;
  }

  onProjectInfoSubmit() {
    this.submitted = true;
    if (this.projectInfo.invalid) {
      return;
    }
  }

  keyPress(event: any) {
    const pattern = /[0-9\+\-\ ]/;
    const inputChar = String.fromCharCode(event.charCode);
    if (event.keyCode !== 8 && !pattern.test(inputChar)) {
      event.preventDefault();
    }
  }

  dataListBuilding() {
    this.monitoringApiService.getBuildingList().subscribe(data => {
      this.dataBuildingList = data.data
    });
  }
  
  dataListRoom() {
    this.monitoringApiService.getListRoomData().subscribe(data => {
      this.dataRoomList = data.data
    });
  }

  dataListMaster() {
    this.monitoringApiService.getMasterListData().subscribe(data => {
      const dataStatus = data.data.find(
        (item) => item.name === "master_status"
      ).headerDetailParam;
      this.dataMasterStatus = dataStatus.filter(item => item.status === "2")
    });
  }

  addData() {}

  cancel() {
    this.router.navigate(["/list-monitoring"]);
  }
}
